==> ideaIC-145.1503.17-sources.jar: com/intellij/remote/ext/CaseCollector.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.remote.ext;

import com.intellij.openapi.util.Ref;
import com.intellij.remote.CredentialsType;
import com.intellij.remote.RemoteSdkAdditionalData;
import com.intellij.util.ArrayUtil;

import java.util.ArrayList;
import java.util.List;

public abstract class CaseCollector {

  public static boolean useRemoteCredentials(RemoteSdkAdditionalData data) {
    final Ref<Boolean> result = Ref.create(true);
    data.switchOnConnectionType(new CaseCollector() {

      @Override
      protected void processWithType(CredentialsTypeEx typeEx, Object credentials) {
        result.set(typeEx.useRemoteCredentials());
      }
    }.collectCases());
    return result.get();
  }

  public CredentialsCase[] collectCases(CredentialsCase... cases) {
    List<CredentialsCase> exCases = new ArrayList<CredentialsCase>();
    for (final CredentialsTypeEx typeEx : CredentialsManager.getInstance().getExTypes()) {
      exCases.add(new CredentialsCase() {
        @Override
        public CredentialsType getType() {
          return typeEx;
        }

        @Override
        public void process(Object credentials) {
          processWithType(typeEx, credentials);
        }
      });
    }
    return ArrayUtil.mergeArrays(cases, exCases.toArray(new CredentialsCase[exCases.size()]));
  }

  protected abstract void processWithType(CredentialsTypeEx typeEx, Object credentials);
}

==> ideaIC-163.13906.16-sources.jar: com/intellij/remote/ext/CaseCollector.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.remote.ext;

import com.intellij.openapi.util.Ref;
import com.intellij.remote.CredentialsType;
import com.intellij.remote.RemoteSdkAdditionalData;
import com.intellij.util.ArrayUtil;

import java.util.ArrayList;
import java.util.List;

public abstract class CaseCollector {

  public static boolean useRemoteCredentials(RemoteSdkAdditionalData data) {
    final Ref<Boolean> result = Ref.create(true);
    data.switchOnConnectionType(new CaseCollector() {

      @Override
      protected void processWithType(CredentialsTypeEx typeEx, Object credentials) {
        result.set(typeEx.useRemoteCredentials());
      }
    }.collectCases());
    return result.get();
  }

  public CredentialsCase[] collectCases(CredentialsCase... cases) {
    List<CredentialsCase> exCases = new ArrayList<>();
    for (final CredentialsTypeEx typeEx : CredentialsManager.getInstance().getExTypes()) {
      exCases.add(new CredentialsCase() {
        @Override
        public CredentialsType getType() {
          return typeEx;
        }

        @Override
        public void process(Object credentials) {
          processWithType(typeEx, credentials);
        }
      });
    }
    return ArrayUtil.mergeArrays(cases, exCases.toArray(new CredentialsCase[exCases.size()]));
  }

  protected abstract void processWithType(CredentialsTypeEx typeEx, Object credentials);
}
